@@ -7,7 +7,9 @@ from .terminal import (
     confirm_uninstall,
 )
 from .fileio import (
+    can_be_deleted,
     copyfile,
+    creation_date,
     get_file_hash,
     get_tmpdir,
     get_tmpfile,
