@@ -5,15 +5,41 @@ __license__ = "MPL 2.0"
 import hashlib
 import errno
 import os
-import stat
 import re
 import shutil
+import stat
 import tempfile
 
 import json
 from shpc.logger import logger
 
 
+def can_be_deleted(path, ignore_files=None):
+    """
+    A path can be deleted if it contains no entries, *or*
+    if the only files are in ignore_files
+    """
+    ignore_files = ignore_files or []
+    if os.path.exists(path):
+        entries = os.listdir(path)
+        if not entries:
+            return True
+        if set(ignore_files).issuperset(entries):
+            return True
+    return False
+
+
+def creation_date(filename):
+    """
+    Get the creation date, and fallback to modified date.
+    """
+    stat = os.stat(filename)
+    try:
+        return stat.st_birthtime
+    except AttributeError:
+        return stat.st_mtime
+
+
 def mkdirp(dirnames):
     """
     Create one or more directories
